@@ -295,8 +295,9 @@ class AdsAPI(object):
         args = {'fields': 'access_token'}
         return self.make_request(path, 'GET', args, batch)
 
-    def create_link_page_post(self, page_id, link, message=None,
-                              picture=None, published=None, batch=False):
+    def create_link_page_post(self, page_id, link, message=None, picture=None,
+                              name=None, caption=None, description=None,
+                              published=None, batch=False):
         """Creates a link page post on the given page."""
         # TODO: this method is calling the API twice; combine them into batch
         page_access_token = self.get_page_access_token(page_id)
@@ -311,6 +312,8 @@ class AdsAPI(object):
             args['picture'] = picture
         if published is not None:
             args['published'] = published
+        if name is not None:
+            args['name'] = name
         return self.make_request(path, 'POST', args, batch)
 
     def create_adcampaign(self, account_id, name, campaign_status,
